#!/bin/bash

#********************************************************************
# TASK: Intermediate results processing
# output file has a convenient delimiter of ":" that can be used to 
# format the file into two columns (col1: field_desc and col2: values)
# However the section "PredictedAffinityChange:...." and 
# "DUETstabilitychange:.." are split over multiple lines and 
# prevent this from happening. Additionally there are other empty lines
# that need to be omiited. In order ensure these sections are not split
# over multiple lines, this script is written.

# Requirements:
# input: output of step2, file containing mcsm results as described above
	# path: "Data/<drug>/input/processed/<filename>"
# output: replaces file in place.
# Therefore first create a copy of the input file
# but rename it to remove the word "MASTER" and add the word "processed"
# file format: .txt

# NOTE: This replaces the file in place!
# the output is a txt file with no newlines and formatting 
# to have the following format "<colname><:><value>
#***********************************************************************
# specify variables for input and output paths and filenames
inpath="${HOME}/git/Data/pyrazinamide/input"
processed_path="/processed"

# Create input file: copy and rename output file of step2
oldfile="${inpath}${processed_path}/complex1_output_MASTER.txt"
newfile="${inpath}${processed_path}/complex1_output_processed.txt"
cp $oldfile $newfile

infile="/complex1_output_processed.txt"
filename="${inpath}${processed_path}${infile}"

echo Input filename is : ${filename}

#sed -i '/PredictedAffinityChange:/ { N; N; N; N; s/\n//g;}' ${filename} \
# | sed -i '/DUETstabilitychange:/ {x; N; N; s/\n//g; p;d;}' ${filename}

# Outputs records separated by a newline, that look something like this:
# PredictedAffinityChange:-2.2log(affinityfoldchange)-Destabilizing
# Mutationinformation:
# Wild-type:L
# Position:4
# Mutant-type:W
# Chain:A
# LigandID:PZA
# Distancetoligand:15.911&Aring;
# DUETstabilitychange:-2.169Kcal/mol
# 
# PredictedAffinityChange:-1.538log(affinityfoldchange)-Destabilizing
# (...etc)

# This script brings everything in a convenient format for further processing in python.
sed -i '/PredictedAffinityChange/ {
N
N
N
N
s/\n//g
}
/DUETstabilitychange:/ {
N
N
s/\n//g
}
/^$/d' ${filename}
